/*
 *   ORXONOX - the hottest 3D action shooter ever to exist
 *                    > www.orxonox.net <
 *
 *
 *   License notice:
 *
 *   This program is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU General Public License
 *   as published by the Free Software Foundation; either version 2
 *   of the License, or (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 *   Author:
 *      Fabian 'x3n' Landau
 *   Co-authors:
 *      ...
 *
 */

/**
    @file OrxoBloxScore.h
    @brief Declaration of the OrxoBloxScore class.
    @ingroup OrxoBlox
*/

#ifndef _OrxoBloxScore_H__
#define _OrxoBloxScore_H__

#include "OrxoBlox/OrxoBloxPrereqs.h"

#include "tools/interfaces/Tickable.h"

#include "overlays/OverlayText.h"

namespace orxonox
{

    /**
    @brief
        The OrxoBloxScore class displays the score for a game of @ref orxonox::OrxoBlox "OrxoBlox".

    @author
        Fabian 'x3n' Landau

    @ingroup OrxoBlox
    */
    class _OrxoBloxExport OrxoBloxScore : public OverlayText, public Tickable
    {
        public:
            OrxoBloxScore(Context* context);
            virtual ~OrxoBloxScore();

            virtual void tick(float dt) override; //!< Creates and sets the caption to be displayed by the OrxoBloxScore.
            virtual void XMLPort(Element& xmlelement, XMLPort::Mode mode) override;
            virtual void changedOwner() override; //!< Is called when the owner changes.

            /**
            @brief Set whether the OrxoBloxScore displays the players' names.
            @param value If true the players' names are displayed.
            */
            inline void setShowName(bool value)
                { this->bShowName_ = value; }
            /**
            @brief Get whether the OrxoBloxScore displays the players' names.
            @return Returns true if the players' names are displayed, false otherwise.
            */
            inline bool getShowName() const
                { return this->bShowName_; }

            /**
            @brief Set whether the OrxoBloxScore displays the players' scores.
            @param value If true the players' scores are displayed.
            */
            inline void setShowScore(bool value)
                { this->bShowScore_ = value; }
            /**
            @brief Get whether the OrxoBloxScore displays the players' scores.
            @return Returns true if the players' scores are displayed, false otherwise.
            */
            inline bool getShowScore() const
                { return this->bShowScore_; }

            /**
            @brief Set whether the OrxoBloxScore displays the left player.
            @param value If true the left player is displayed.
            */
            inline void setShowPlayer(bool value)
                { this->bShowPlayer_ = value; }
            /**
            @brief Get whether the OrxoBloxScore displays the left player.
            @return Returns true if the left player is displayed, false otherwise.
            */
            inline bool getShowPlayer() const
                { return this->bShowPlayer_; }

/*
            /**
            @brief Set whether the OrxoBloxScore displays the right player.
            @param value If true the right player is displayed.
            
            inline void setShowRightPlayer(bool value)
                { this->bShowRightPlayer_ = value; }
            /**
            @brief Get whether the OrxoBloxScore displays the right player.
            @return Returns true if the right player is displayed, false otherwise.
            
            inline bool getShowRightPlayer() const
                { return this->bShowRightPlayer_; }
*/
        private:
            OrxoBlox* owner_; //!< The OrxoBlox game that owns this OrxoBloxScore.
            bool bShowName_; //!< Whether the names of the players are shown.
            bool bShowScore_; //!< Whether the score of the players is shown.
            bool bShowPlayer_; //!< Whether the left player is shown.
            //bool bShowRightPlayer_; //!< Whether the right player is shown.
            WeakPtr<PlayerInfo> player1_; //!< Store information about left player permanently.
            WeakPtr<PlayerInfo> player2_; //!< Same for the right player. To end the game properly.
            WorldSound* scoreSound_;

    };
}
#endif /* _OrxoBloxScore_H__ */
